@@ -122,18 +122,3 @@ class Party(models.Model):
             self.id = uuid.uuid4()
         super(Party, self).save(*args, **kwargs)
 
-
-class LimitedAccessToken(models.Model):
-    """
-    After a user verified their phone number, a LimitedAccessToken object associated with that user's phone number should
-    be created and returned to the user. This token should be used to authorize Login, Register and UploadPreKeyBundle
-    requests.
-    """
-    hash = models.CharField(max_length=128, primary_key=True)
-    salt = models.CharField(max_length=16, unique=True)
-    phone = models.CharField(unique=True, max_length=50)
-    timestamp = models.DateTimeField(auto_now_add=True)
-
-    def __str__(self):
-        return self.phone
-
